… | OiRA

Help

1. Voorbereiding
3. Inventarisatie + Evaluatie
   1. 1 Commercial manned guarding
   2. Ω Bijkomende risico’s (door u toegevoegd)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Niet bekekeken
   - Overgeslagen
   - Risico niet aanwezig
   - Risico aanwezig
4. Plan van aanpak
5. Rapport
6. Status 0%

## Beschrijf het risico…

Is het risico aanvaardbaar? Nee, er zijn meer maatregelen nodig Ja, het resterende risico is aanvaardbaar

Select the priority of this risk Low Medium High
Informatie
Invoegen afbeeldinglabel_upload_image
Opmerkingen

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More